@@ -3,16 +3,16 @@
 # Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -44,6 +44,8 @@ from formatting import Formatting
 from speech_generator import SpeechGenerator
 from script_utilities import Utilities
 
+_settingsManager = getattr(orca, '_settingsManager')
+
 ########################################################################
 #                                                                      #
 # The Evolution script class.                                          #
@@ -332,7 +334,7 @@ class Script(default.Script):
         self.rolesList = [pyatspi.ROLE_TEXT, \
                           pyatspi.ROLE_PANEL, \
                           pyatspi.ROLE_TABLE_CELL]
-        if settings.readTableCellRow \
+        if _settingsManager.getSetting('readTableCellRow') \
             and (self.utilities.hasMatchingHierarchy(
                     event.source, self.rolesList)):
             debug.println(self.debugLevel,
@@ -385,8 +387,9 @@ class Script(default.Script):
 
         self.rolesList = [pyatspi.ROLE_TABLE_CELL, \
                           pyatspi.ROLE_TREE_TABLE]
-        if settings.readTableCellRow and self.utilities.hasMatchingHierarchy(
-                event.source, self.rolesList):
+        if _settingsManager.getSetting('readTableCellRow') \
+                and self.utilities.hasMatchingHierarchy(event.source,
+                                                        self.rolesList):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - mail view: " \
                           + "message header list.")
@@ -397,7 +400,7 @@ class Script(default.Script):
             # for the duration of this code section, then resetting it to
             # True at the end.
             #
-            settings.readTableCellRow = False
+            _settingsManager.setSetting('readTableCellRow', False)
 
             parent = event.source.parent
             parentTable = parent.queryTable()
@@ -412,7 +415,7 @@ class Script(default.Script):
             if self.lastMessageRow == row:
                 default.Script.locusOfFocusChanged(self, event,
                                            oldLocusOfFocus, newLocusOfFocus)
-                settings.readTableCellRow = True
+                _settingsManager.setSetting('readTableCellRow', True)
                 return
 
             # This is an indication of whether we should speak all the table
@@ -423,19 +426,19 @@ class Script(default.Script):
             # changed, then speak all the table cells.
             #
             justDeleted = False
-            if isinstance(orca_state.lastInputEvent,
-                          input_event.KeyboardEvent):
-                string = orca_state.lastNonModifierKeyEvent.event_string
-                if string == "Delete":
-                    justDeleted = True
+            string, mods = self.utilities.lastKeyAndModifiers()
+            if string == "Delete":
+                justDeleted = True
 
             speakAll = (self.lastMessageRow != row) or \
                        ((row == 0 or row == parentTable.nRows-1) and \
                         self.lastMessageColumn == column) or \
                        justDeleted
 
-            savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
-            savedSpeechVerbosityLevel = settings.speechVerbosityLevel
+            savedBrailleVerbosityLevel = \
+                _settingsManager.getSetting('brailleVerbosityLevel')
+            savedSpeechVerbosityLevel = \
+                _settingsManager.getSetting('speechVerbosityLevel')
 
             brailleRegions = []
             cellWithFocus = None
@@ -527,10 +530,12 @@ class Script(default.Script):
                         #
                         if (verbose or (checkbox and column == i)) \
                            and not useAlternativeName:
-                            settings.brailleVerbosityLevel = \
-                                settings.VERBOSITY_LEVEL_BRIEF
-                            settings.speechVerbosityLevel = \
-                                settings.VERBOSITY_LEVEL_BRIEF
+                            _settingsManager.setSetting(
+                                'brailleVerbosityLevel',
+                                settings.VERBOSITY_LEVEL_BRIEF)
+                            _settingsManager.setSetting(
+                                'speechVerbosityLevel',
+                                settings.VERBOSITY_LEVEL_BRIEF)
 
                             utterances = speechGen.generateSpeech(
                                 header,
@@ -554,13 +559,14 @@ class Script(default.Script):
                         # then speak/braille "attachment".
                         #
                         if verbose:
-                            settings.brailleVerbosityLevel = \
-                                settings.VERBOSITY_LEVEL_VERBOSE
+                            level = settings.VERBOSITY_LEVEL_VERBOSE
                         else:
-                            settings.brailleVerbosityLevel = \
-                                settings.VERBOSITY_LEVEL_BRIEF
-                        settings.speechVerbosityLevel = \
-                            savedSpeechVerbosityLevel
+                            level = settings.VERBOSITY_LEVEL_BRIEF
+                        _settingsManager.setSetting(
+                            'brailleVerbosityLevel', level)
+                        _settingsManager.setSetting(
+                            'speechVerbosityLevel',
+                            savedSpeechVerbosityLevel)
                         utterances = speechGen.generateSpeech(
                             cell,
                             includeContext=False,
@@ -621,11 +627,13 @@ class Script(default.Script):
             if brailleRegions != []:
                 self.displayBrailleRegions([brailleRegions, cellWithFocus])
 
-            settings.brailleVerbosityLevel = savedBrailleVerbosityLevel
-            settings.speechVerbosityLevel = savedSpeechVerbosityLevel
+            _settingsManager.setSetting(
+                'brailleVerbosityLevel', savedBrailleVerbosityLevel)
+            _settingsManager.setSetting(
+                'speechVerbosityLevel', savedSpeechVerbosityLevel)
             self.lastMessageColumn = column
             self.lastMessageRow = row
-            settings.readTableCellRow = True
+            _settingsManager.setSetting('readTableCellRow', True)
             return
 
         # 4) Calendar view: day view: tabbing to day with appts.
@@ -879,26 +887,24 @@ class Script(default.Script):
             # the last key pressed wasn't a navigation key, then just
             # ignore it. See bug #490317 for more details.
             #
-            if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
-                if self.utilities.isSameObject(event.source.parent,
-                                     orca_state.locusOfFocus.parent):
-                    lastKey = orca_state.lastNonModifierKeyEvent.event_string
-                    if self.utilities.isMessageBody(orca_state.locusOfFocus) \
-                       and lastKey not in ["Left", "Right", "Up", "Down",
-                                           "Home", "End", "Return", "Tab"]:
-                        return
+            if self.utilities.isSameObject(event.source.parent,
+                                           orca_state.locusOfFocus.parent):
+                lastKey, mods = self.utilities.lastKeyAndModifiers()
+                if self.utilities.isMessageBody(orca_state.locusOfFocus) \
+                   and lastKey not in ["Left", "Right", "Up", "Down",
+                                       "Home", "End", "Return", "Tab"]:
+                    return
 
-                    # If the last keyboard event was a "same line"
-                    # navigation key, then pass this event onto the
-                    # onCaretMoved() method in the parent class for
-                    # speaking. See bug #516565 for more details.
-                    #
-                    if lastKey in ["Left", "Right", "Home", "End"]:
-                        default.Script.onCaretMoved(self, event)
-                        return
+                # If the last keyboard event was a "same line"
+                # navigation key, then pass this event onto the
+                # onCaretMoved() method in the parent class for
+                # speaking. See bug #516565 for more details.
+                #
+                if lastKey in ["Left", "Right", "Home", "End"]:
+                    default.Script.onCaretMoved(self, event)
+                    return
 
             self.message_panel = event.source.parent.parent
-
             self.presentMessageLine(event.source, newLocusOfFocus)
             return
 
@@ -1035,28 +1041,24 @@ class Script(default.Script):
         # prior to speaking the actual message that gets focus.
         # See bug #347964.
         #
-        if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent) \
-           and orca_state.lastNonModifierKeyEvent:
-            string = orca_state.lastNonModifierKeyEvent.event_string
-            if string == "Delete":
-                rolesList = [pyatspi.ROLE_TABLE_CELL,
-                             pyatspi.ROLE_TREE_TABLE,
-                             pyatspi.ROLE_UNKNOWN,
-                             pyatspi.ROLE_SCROLL_PANE]
-                oldLocusOfFocus = orca_state.locusOfFocus
-                if self.utilities.hasMatchingHierarchy(
-                        event.source, rolesList) \
-                   and self.utilities.hasMatchingHierarchy(
-                        oldLocusOfFocus, rolesList):
-                    parent = event.source.parent
-                    parentTable = parent.queryTable()
-                    newIndex = self.utilities.cellIndex(event.source)
-                    newRow = parentTable.getRowAtIndex(newIndex)
-                    oldIndex = self.utilities.cellIndex(oldLocusOfFocus)
-                    oldRow = parentTable.getRowAtIndex(oldIndex)
-                    nRows = parentTable.nRows
-                    if (newRow != oldRow) and (oldRow != nRows):
-                        return
+        string, mods = self.utilities.lastKeyAndModifiers()
+        if string == "Delete":
+            roles = [pyatspi.ROLE_TABLE_CELL,
+                     pyatspi.ROLE_TREE_TABLE,
+                     pyatspi.ROLE_UNKNOWN,
+                     pyatspi.ROLE_SCROLL_PANE]
+            oldLocusOfFocus = orca_state.locusOfFocus
+            if self.utilities.hasMatchingHierarchy(event.source, roles) \
+               and self.utilities.hasMatchingHierarchy(oldLocusOfFocus, roles):
+                parent = event.source.parent
+                parentTable = parent.queryTable()
+                newIndex = self.utilities.cellIndex(event.source)
+                newRow = parentTable.getRowAtIndex(newIndex)
+                oldIndex = self.utilities.cellIndex(oldLocusOfFocus)
+                oldRow = parentTable.getRowAtIndex(oldIndex)
+                nRows = parentTable.nRows
+                if (newRow != oldRow) and (oldRow != nRows):
+                    return
 
         # For everything else, pass the event onto the parent class
         # to be handled in the default way.
@@ -1136,8 +1138,9 @@ class Script(default.Script):
 
         [string, caretOffset, startOffset] = self.getTextLineAtCaret(obj)
         self.updateBraille(newLocusOfFocus)
-        if settings.enableSpeechIndentation:
-            self.speakTextIndentation(obj, string)
+        result = self.speechGenerator.generateTextIndentation(obj, line=string)
+        if result:
+            speech.speak(result[0])
         line = self.utilities.adjustForRepeats(string)
 
         if self.utilities.speakBlankLine(obj):
@@ -1194,10 +1197,12 @@ class Script(default.Script):
         speechGen = self.speechGenerator
 
         savedSpeechVerbosityLevel = settings.speechVerbosityLevel
-        settings.speechVerbosityLevel = settings.VERBOSITY_LEVEL_BRIEF
+        _settingsManager.setSetting(
+            'speechVerbosityLevel', settings.VERBOSITY_LEVEL_BRIEF)
         utterances = speechGen.generateSpeech(tab)
         speech.speak(utterances)
-        settings.speechVerbosityLevel = savedSpeechVerbosityLevel
+        _settingsManager.setSetting(
+            'speechVerbosityLevel', savedSpeechVerbosityLevel)
 
         self.displayBrailleRegions(brailleGen.generateBraille(tab))
 
@@ -1239,12 +1244,14 @@ class Script(default.Script):
 
         # Determine the correct "say all by" mode to use.
         #
-        if settings.sayAllStyle == settings.SAYALL_STYLE_SENTENCE:
+        sayAllStyle = _settingsManager.getSetting('sayAllStyle')
+        if sayAllStyle == settings.SAYALL_STYLE_SENTENCE:
             mode = pyatspi.TEXT_BOUNDARY_SENTENCE_END
-        elif settings.sayAllStyle == settings.SAYALL_STYLE_LINE:
+        elif sayAllStyle == settings.SAYALL_STYLE_LINE:
             mode = pyatspi.TEXT_BOUNDARY_LINE_START
         else:
             mode = pyatspi.TEXT_BOUNDARY_LINE_START
+        voices = _settingsManager.getSetting('voices')
 
         while not done:
             panel = htmlPanel.getChildAtIndex(i)
@@ -1268,9 +1275,9 @@ class Script(default.Script):
                        len(mystr) == 0 or mystr[len(mystr)-1] in '.?!':
                         string = self.utilities.adjustForRepeats(string)
                         if string.decode("UTF-8").isupper():
-                            voice = settings.voices[settings.UPPERCASE_VOICE]
+                            voice = voices[settings.UPPERCASE_VOICE]
                         else:
-                            voice = settings.voices[settings.DEFAULT_VOICE]
+                            voice = voices[settings.DEFAULT_VOICE]
 
                         if not textObjs:
                             textObjs.append(textObj)
@@ -1297,9 +1304,9 @@ class Script(default.Script):
         if len(string) != 0:
             string = self.utilities.adjustForRepeats(string)
             if string.decode("UTF-8").isupper():
-                voice = settings.voices[settings.UPPERCASE_VOICE]
+                voice = voices[settings.UPPERCASE_VOICE]
             else:
-                voice = settings.voices[settings.DEFAULT_VOICE]
+                voice = voices[settings.DEFAULT_VOICE]
 
             yield [speechserver.SayAllContext(textObjs, string,
                                               startOffset, endOffset),
